@@ -1,7 +1,7 @@
 package usw;
 use 5.012005;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use Encode qw(is_utf8 encode_utf8 decode_utf8);
 use utf8();
@@ -14,13 +14,17 @@ sub import {
     strict->import;
     warnings->import( 'all', FATAL => 'recursion' );
 
-    binmode \*STDOUT, ':encoding(UTF-8)';
-    binmode \*STDERR, ':encoding(UTF-8)';
+    my $out = first { $_ =~ /^cp\d+$/ } @_;
+    $out ||= 'UTF-8';
+    binmode \*STDIN,  ":encoding($out)";
+    binmode \*STDOUT, ":encoding($out)";
+    binmode \*STDERR, ":encoding($out)";
     return unless @_;
 
     $SIG{__WARN__} = \&_redecode if first { $_ eq 'warn' } @_;
     $SIG{__DIE__}  = sub { die _redecode(@_) }
         if first { $_ eq 'die' } @_;
+
     return;
 }
 
@@ -85,12 +89,23 @@ Since version 0.03, you can write like this:
 
  use usw qw(warn die);
 
-these options replaces C<$SIG{__WARN__}> or/and C<$SIG{__DIE__}>
+These options replaces C<$SIG{__WARN__}> or/and C<$SIG{__DIE__}>
 to avoid the bug(This may be a strange specification)
-of encoding only the file path.
+of encoding only the file path like that:
+
+ 宣言あり at t/script/00_è­¦åãã.pl line 19.
 
 This import is B<only> if written.
 
+Since version 0.04, you can write like this:
+
+ use usw qw(cp932);
+
+This option changes at once C<STDIN>,C<STDOUT>,C<STDERR> to C<cp\d+>
+
+defaults to C<UTF-8> and should B<NOT> be set except on Windows.
+
+
 =head1 LICENSE
 
 Copyright (C) worthmine.
